@@ -6,15 +6,15 @@ use warnings;
 
 =head1 NAME
 
-VSGDR::UnitTest::TestSet - The great new VSGDR::UnitTest::TestSet!
+VSGDR::UnitTest::TestSet - Sealed class for Microsoft Visual Studio Database Edition UnitTest Utility Suite by Ded MedVed
 
 =head1 VERSION
 
-Version 1.00
+Version 1.22_01
 
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.22_01';
 
 
 use autodie qw(:all);
@@ -29,7 +29,6 @@ use Clone;
 
 use base qw(Clone) ;
 
-our $VERSION    = "0.01";
 our $AUTOLOAD ;
 my %ok_field ;
 # Authorize four attribute fields
@@ -307,7 +306,25 @@ __DATA__
 =head1 SYNOPSIS
 
 Sealed unit.  No user serviceable parts.
+This module, and all sub-modules exist only to support the suite of applications packaged with it.
+The applications offer support to creators and maintainers of Microsoft Visual Studio
+Database Project Unit tests, particularly those frustrated by the VS interface to these tests,
+who are also comfortable using perl software from the command line.
 
+Support is given for VS2008 and VS2010.
+Full support is offered for:-
+    Scalar, EmptyResultSet, NotEmptyResultSet, RowCount conditions.
+Partial support for:-
+    ExecutionTime, ExpectedSchema, Inconclusive, Checksum conditions.
+No support is offered for bespoke conditions, apart from what you can add yourself.
+No support is offered for any unit tests that have been manually edited to add code Attributes, or alter the transaction mode etc etc.
+    
+The suite offers scripts to generate unit tests from sql scripts, merge unit test files, split apart unit test files, extract the sql from unit test files, delete
+tests from unit test files, disable test conditions, report over unit test files, and run unit test files, with better reporting of test failures
+than MSTest or Visual Studio. It can also translate unit test files from VB to C# and vice-versa, as well as to
+Excel Spreadsheet, or XML.
+The test runner cannot check ExecutionTime, ExpectedSchema, Inconclusive, Checksum conditions.
+This is because it is pure perl, and has no access to .NET internals, or the database connection code used by .NET.
 
 =head1 AUTHOR
 
